@@ -287,7 +287,7 @@ int amf_namf_comm_handle_n1_n2_message_transfer(
                 header.resource.component[1] = amf_ue->supi;
                 header.resource.component[2] =
                     (char *)OGS_SBI_RESOURCE_NAME_N1_N2_MESSAGES;
-                header.resource.component[3] = sess->sm_context.ref;
+                header.resource.component[3] = sess->sm_context_ref;
 
                 sendmsg.http.location = ogs_sbi_server_uri(server, &header);
 
@@ -349,7 +349,7 @@ int amf_namf_comm_handle_n1_n2_message_transfer(
             header.resource.component[1] = amf_ue->supi;
             header.resource.component[2] =
                 (char *)OGS_SBI_RESOURCE_NAME_N1_N2_MESSAGES;
-            header.resource.component[3] = sess->sm_context.ref;
+            header.resource.component[3] = sess->sm_context_ref;
 
             sendmsg.http.location = ogs_sbi_server_uri(server, &header);
 
@@ -423,7 +423,7 @@ int amf_namf_comm_handle_n1_n2_message_transfer(
                 header.resource.component[1] = amf_ue->supi;
                 header.resource.component[2] =
                     (char *)OGS_SBI_RESOURCE_NAME_N1_N2_MESSAGES;
-                header.resource.component[3] = sess->sm_context.ref;
+                header.resource.component[3] = sess->sm_context_ref;
 
                 sendmsg.http.location = ogs_sbi_server_uri(server, &header);
 
@@ -595,6 +595,7 @@ int amf_namf_callback_handle_sm_context_status(
         sess->n2_released == true &&
         sess->resource_status == OpenAPI_resource_status_RELEASED) {
         amf_nsmf_pdusession_handle_release_sm_context(
+                amf_ue, ran_ue_find_by_id(sess->ran_ue_id),
                 sess, AMF_RELEASE_SM_CONTEXT_NO_STATE);
     }
 
@@ -782,8 +783,6 @@ static int update_rat_res_array(cJSON *json_restrictions,
 static int update_rat_res(OpenAPI_change_item_t *item_change,
                           OpenAPI_list_t *restrictions)
 {
-    cJSON* json = item_change->new_value->json;
-    cJSON* json_restrictions;
 
     if (!item_change->path) {
         return OGS_ERROR;
@@ -792,7 +791,18 @@ static int update_rat_res(OpenAPI_change_item_t *item_change,
     switch (item_change->op) {
     case OpenAPI_change_type_REPLACE:
     case OpenAPI_change_type_ADD:
+    {
+        cJSON *json;
+
+        if ((!item_change->new_value) || (!item_change->new_value->json)) {
+            ogs_error("No 'new_value' field present");
+            return OGS_ERROR;
+        }
+        json = item_change->new_value->json;
+
         if (!strcmp(item_change->path, "")) {
+            cJSON *json_restrictions;
+
             if (!cJSON_IsObject(json)) {
                 ogs_error("Invalid type of am-data");
             }
@@ -813,6 +823,7 @@ static int update_rat_res(OpenAPI_change_item_t *item_change,
             return update_rat_res_add_one(json, restrictions, i);
         }
         return OGS_OK;
+    }
 
     case OpenAPI_change_type__REMOVE:
         if (!strcmp(item_change->path, "")) {
@@ -1475,9 +1486,9 @@ static OpenAPI_list_t *amf_namf_comm_encode_ue_session_context_list(
         ogs_assert(sNSSAI);
 
         PduSessionContext->pdu_session_id = sess->psi;
-        ogs_assert(sess->sm_context.resource_uri);
+        ogs_assert(sess->sm_context_resource_uri);
         PduSessionContext->sm_context_ref =
-            ogs_strdup(sess->sm_context.resource_uri);
+            ogs_strdup(sess->sm_context_resource_uri);
 
         sNSSAI->sst = sess->s_nssai.sst;
         sNSSAI->sd = ogs_s_nssai_sd_to_string(sess->s_nssai.sd);
@@ -1802,9 +1813,9 @@ static void amf_namf_comm_decode_ue_session_context_list(
         ogs_freeaddrinfo(addr);
         ogs_freeaddrinfo(addr6);
 
-        sess->sm_context.resource_uri =
+        sess->sm_context_resource_uri =
             ogs_strdup(PduSessionContext->sm_context_ref);
-        sess->sm_context.ref =
+        sess->sm_context_ref =
             ogs_strdup(message.h.resource.component[1]);
 
         memset(&sess->s_nssai, 0, sizeof(sess->s_nssai));
@@ -1885,7 +1896,15 @@ int amf_namf_comm_handle_registration_status_update_request(
                     uint8_t psi = *(double *)node->data;
                     sess = amf_sess_find_by_psi(amf_ue, psi);
                     if (SESSION_CONTEXT_IN_SMF(sess)) {
-                        amf_sbi_send_release_session(ran_ue, sess, AMF_RELEASE_SM_CONTEXT_NO_STATE);
+                        amf_nsmf_pdusession_sm_context_param_t param;
+
+                        memset(&param, 0, sizeof(param));
+                        param.ue_location = true;
+                        param.ue_timezone = true;
+
+                        amf_sbi_send_release_session(
+                                ran_ue, sess,
+                                AMF_RELEASE_SM_CONTEXT_NO_STATE, &param);
                     } else {
                         ogs_error("[%s] No Session Context PSI[%d]",
                                 amf_ue->supi, psi);
