@@ -127,6 +127,10 @@ uint8_t mme_s6a_handle_ula(
             return OGS_NAS_EMM_CAUSE_NO_EPS_BEARER_CONTEXT_ACTIVATED;
         }
 
+        /* Determine S1AP procedure and store it for reuse */
+        mme_ue->tracking_area_update_accept_proc =
+            S1AP_ProcedureCode_id_InitialContextSetup;
+
         /* Update CSMAP from Tracking area update request */
         mme_ue->csmap = mme_csmap_find_by_tai(&mme_ue->tai);
         if (mme_ue->csmap &&
@@ -137,13 +141,12 @@ uint8_t mme_s6a_handle_ula(
              mme_ue->nas_eps.update.value ==
              OGS_NAS_EPS_UPDATE_TYPE_COMBINED_TA_LA_UPDATING_WITH_IMSI_ATTACH)) {
 
-            mme_ue->tracking_area_update_request_type =
-                MME_TAU_TYPE_UNPROTECTED_INGERITY;
             ogs_assert(OGS_OK == sgsap_send_location_update_request(mme_ue));
 
         } else {
+            ogs_info("[%s] TAU accept(Diameter ULA)", mme_ue->imsi_bcd);
             r = nas_eps_send_tau_accept(mme_ue,
-                    S1AP_ProcedureCode_id_InitialContextSetup);
+                    mme_ue->tracking_area_update_accept_proc);
             ogs_expect(r == OGS_OK);
             ogs_assert(r != OGS_ERROR);
         }
